@@ -1,7 +1,7 @@
 import sys
 import time
 
-def animated_input(prompt, delay=0.1):
+def animated_input(prompt="Example prompt for input:", delay=0.05):
     result = ""
     for character in prompt:
         sys.stdout.write(character)
